% OUT  -  output argument in a given format into character file
% %%%
%	arg	argument
%	form	format string (see fprintf)
%	fname	file name, including  standard names as 'prn', ...
%
%     Examples:
%     ~~~~~~~~
%  out(A)        % Output matrix A on screen in '%9.4f' format
%  out(k,'%4i\n')          % Output column of integers
%  out(Z,'E','cmplxZ.dat') % Complex matrix in '%11.3e'format
%                            to the file 'cmplxZ.dat'

function out(arg, form, fname)
%        ~~~~~~~~~~~~~~~~~~~~~
if nargin<3, fname = 1; end

if isstr(arg)
   if nargin<2
      fprintf(fname,arg)
   else
      fprintf(fname,[arg, form])
   end
else
   [m,n] = size(arg);
   frme = ' %11.3e';
   frmf = ' %9.4f';
   if any(~isreal(arg)) %          COMPLEX :
      if nargin<2 | ~strcmp(form,'E')
         form = [frmf frmf 'i '];
      else
         form = [frme frme 'i '];
      end
      for i = 1:m
         fprintf(fname,form,[real(arg(i,:)), imag(arg(i,:))])
         fprintf(fname,'\n')
      end
   else %                          REAL:
      if nargin>1 
         if strcmp(form,'E')
            form = frme;
         end
      else
         form = frmf;
      end
      for i = 1:m
         fprintf(fname,form,arg(i,:))
         fprintf(fname,'\n')
      end
   end
end
